@@ -30,7 +30,7 @@ use Params::Util qw(_INSTANCE _STRING _ARRAY _ARRAY0 _HASH0 _HASH);
 
 #use locale;
 
-$VERSION = '1.33';
+$VERSION = '1.401';
 
 sub new
 {
@@ -177,16 +177,18 @@ sub CREATE ($$$)
         # AS IMPORT
         if ( $subquery =~ m/^IMPORT/i )
         {
-            $sth = $data->{Database}->prepare("SELECT * FROM $subquery");
-            $sth->execute(@$params);
+            $sth = $data->{Database}->prepare("SELECT * FROM $subquery")
+              or return $self->do_err( $data->{Database}->errstr() );
+            $sth->execute(@$params) or return $self->do_err( $sth->errstr() );
             $names = $sth->{NAME};
         }
 
         # AS SELECT
         else
         {
-            $sth = $data->{Database}->prepare($subquery);
-            $sth->execute();
+            $sth = $data->{Database}->prepare($subquery)
+              or return $self->do_err( $data->{Database}->errstr() );
+            $sth->execute() or return $self->do_err( $sth->errstr() );
             $names = $sth->{NAME};
         }
         $names = $sth->{NAME} unless defined $names;
@@ -240,7 +242,8 @@ sub CALL
 }
 
 my $enoentstr = "Cannot open .*\(" . Errno::ENOENT . "\)";
-my $enoentrx  = qr/$enoentstr/;
+my $eabstrstr = "Abstract method .*::open_table called";
+my $notblrx   = qr/(?:$enoentstr|$eabstrstr)/;
 
 sub DROP ($$$)
 {
@@ -252,14 +255,14 @@ sub DROP ($$$)
         ($eval) = $self->open_tables( $data, 0, 1 );
     };
     if (     $self->{ignore_missing_table}
-         and ( $@ or @err )
-         and grep { $_ =~ $enoentrx } ( @err, $@ ) )
+         and ( $@ or @err or $self->{errstr} )
+         and grep { $_ =~ $notblrx } ( @err, $@, $self->{errstr} ) )
     {
-        $@ = '';
         return ( -1, 0 );
     }
 
-    $self->do_err( $@ || $err[0] ) if ( $@ || @err );
+    return if $self->{errstr};
+    return $self->do_err( $@ || $err[0] ) if ( $@ || @err );
 
     #    return undef unless $eval;
     return ( -1, 0 ) unless $eval;
@@ -302,7 +305,7 @@ sub INSERT ($$$)
                 $val = $self->row_values( $k, $i );
                 if ( defined( _INSTANCE( $val, 'SQL::Statement::Param' ) ) )
                 {
-                    $val = $eval->param( $val->num() );
+                    $val = $eval->param( $val->idx() );
                 }
                 elsif ( defined( _INSTANCE( $val, 'SQL::Statement::Term' ) ) )
                 {
@@ -959,7 +962,7 @@ sub SELECT($$)
     {
         if ( _INSTANCE( $column, 'SQL::Statement::Param' ) )
         {
-            my $val = $eval->param( $column->num() );
+            my $val = $eval->param( $column->idx() );
             if ( -1 != ( my $idx = index( $val, '.' ) ) )
             {
                 $col = substr( $val, 0, $idx );
@@ -1603,7 +1606,7 @@ sub verify_columns
         {
             defined( _INSTANCE( $self->{sort_spec_list}->[$n], 'SQL::Statement::Order' ) ) and next;
             my ( $newcol, $direction ) = each %{ $self->{sort_spec_list}->[$n] };
-            my $desc = $direction eq "DESC";
+            my $desc = $direction && ( $direction eq "DESC" );    # ($direction || "ASC") eq "DESC";
 
             # XXX parse order by like group by and select list
             $i = -2;
@@ -1615,8 +1618,8 @@ sub verify_columns
             defined($table) and $col = $table . "." . $col;
             $self->{sort_spec_list}->[$n] = SQL::Statement::Order->new(
                 col => SQL::Statement::Util::Column->new(
-                    $col,      # column name
-                    $table,    # table name
+                    $col,                                         # column name
+                    $table,                                       # table name
                     SQL::Statement::ColumnValue->new( $self, $col ),    # term
                     $newcol                                             # display name
                                                         ),
@@ -2262,12 +2265,12 @@ package SQL::Statement::Param;
 
 sub new
 {
-    my ( $class, $num ) = @_;
-    my $self = { 'num' => $num };
+    my ( $class, $idx ) = @_;
+    my $self = { 'idx' => $idx };
     return bless( $self, $class );
 }
 
-sub num ($) { $_[0]->{num}; }
+sub idx ($) { $_[0]->{idx}; }
 
 package SQL::Statement::Table;
 
